"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasDefinitelyTyped = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@yarnpkg/core");
const algoliasearch_1 = tslib_1.__importDefault(require("algoliasearch"));
// Note that the appId and appKey are specific to Yarn's plugin-typescript - please
// don't use them anywhere else without asking Algolia's permission
const ALGOLIA_API_KEY = `e8e1bd300d860104bb8c58453ffa1eb4`;
const ALGOLIA_APP_ID = `OFCNCOG2CU`;
const hasDefinitelyTyped = async (descriptor, configuration) => {
    const stringifiedIdent = core_1.structUtils.stringifyIdent(descriptor);
    const algoliaClient = createAlgoliaClient(configuration);
    const index = algoliaClient.initIndex(`npm-search`);
    try {
        const packageInfo = await index.getObject(stringifiedIdent, { attributesToRetrieve: [`types`] });
        return packageInfo.types?.ts === `definitely-typed`;
    }
    catch (_e) {
        return false;
    }
};
exports.hasDefinitelyTyped = hasDefinitelyTyped;
const createAlgoliaClient = (configuration) => {
    const requester = {
        async send(request) {
            try {
                const response = await core_1.httpUtils.request(request.url, request.data || null, {
                    configuration,
                    headers: request.headers,
                });
                return {
                    content: response.body,
                    isTimedOut: false,
                    status: response.statusCode,
                };
            }
            catch (error) {
                return {
                    content: error.response.body,
                    isTimedOut: false,
                    status: error.response.statusCode,
                };
            }
        }
    };
    return (0, algoliasearch_1.default)(ALGOLIA_APP_ID, ALGOLIA_API_KEY, { requester });
};
